@@ -6,28 +6,29 @@ scopes = []
 class Scope:
     def __init__(self, globals=None):
         from .builtins import namespace as builtins
-        self.namespaces = [
-            globals if globals is not None else {},
-            builtins,
-        ]
+        self.builtins = builtins
+        self.globals = globals if globals is not None else {}
         self.locals = {}
 
-    def namespace(self, name):
-        namespaces = [
-            self.locals if self.locals is not None else {},
-            *self.namespaces,
-        ]
-        for namespace in namespaces:
+    def find(self, name):
+        for namespace in self.namespaces():
             if name in namespace:
                 return namespace
         return None
 
     def resolve(self, name):
-        namespace = self.namespace(name)
+        namespace = self.find(name)
         if namespace is None:
             return None
         return namespace[name]
 
+    def namespaces(self, with_builtins=True):
+        yield self.locals
+        yield self.globals
+        if with_builtins:
+            yield self.builtins
+
+
 def push_scope(globals):
     scopes.append(Scope(globals))
 
